
.. |disabled| image:: img/disabled_icon.svg
   :height: 25px
   :width: 25px
   :target: configuring.html#configuring-disabled-rules

.. |warning| image:: img/warning_icon.svg
   :height: 25px
   :width: 25px
   :target: rule_severity.html

.. |error| image:: img/error_icon.svg
   :height: 25px
   :width: 25px
   :target: rule_severity.html

.. |unfixable| image:: img/unfixable_icon.svg
   :height: 25px
   :width: 25px
   :target: unfixable_rules.html

.. |phase_1| image:: img/phase_1_icon.svg
   :height: 25px
   :width: 25px
   :target: phases.html

.. |phase_2| image:: img/phase_2_icon.svg
   :height: 25px
   :width: 25px
   :target: phases.html

.. |phase_3| image:: img/phase_3_icon.svg
   :height: 25px
   :width: 25px
   :target: phases.html

.. |phase_4| image:: img/phase_4_icon.svg
   :height: 25px
   :width: 25px
   :target: phases.html

.. |phase_5| image:: img/phase_5_icon.svg
   :height: 25px
   :width: 25px
   :target: phases.html

.. |phase_6| image:: img/phase_6_icon.svg
   :height: 25px
   :width: 25px
   :target: phases.html

.. |phase_7| image:: img/phase_7_icon.svg
   :height: 25px
   :width: 25px
   :target: phases.html

.. |indent| image:: img/indent.svg
   :height: 25px
   :width: 74.32182491px
   :target: rule_groups.html

.. |length| image:: img/length.svg
   :height: 25px
   :width: 74.32182491px
   :target: rule_groups.html

.. |blank_line| image:: img/blank_line.svg
   :height: 25px
   :width: 86.65228113px
   :target: rule_groups.html

.. |whitespace| image:: img/whitespace.svg
   :height: 25px
   :width: 86.65228113px
   :target: rule_groups.html

.. |structure| image:: img/structure.svg
   :height: 25px
   :width: 86.65228113px
   :target: rule_groups.html

.. |alignment| image:: img/alignment.svg
   :height: 25px
   :width: 86.65228113px
   :target: rule_groups.html

.. |structure_optional| image:: img/structure_optional.svg
   :height: 25px
   :width: 142.1393342px
   :target: rule_groups.html

.. |case| image:: img/case.svg
   :height: 25px
   :width: 86.65228113px
   :target: rule_groups.html

.. |case_keyword| image:: img/case_keyword.svg
   :height: 25px
   :width: 105.1479655px
   :target: rule_groups.html

.. |case_name| image:: img/case_name.svg
   :height: 25px
   :width: 86.65228113px
   :target: rule_groups.html

.. |case_label| image:: img/case_label.svg
   :height: 25px
   :width: 86.65228113px
   :target: rule_groups.html

.. |naming| image:: img/naming.svg
   :height: 25px
   :width: 86.65228113px
   :target: rule_groups.html
